
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <stdlib.h>


#define MAXN  14


class tnode
{
public:
   int nums[MAXN];   /* negative value means pointer */
   tnode* ptrs[MAXN];
   char ops[MAXN];   /* operatory */
   int numc;
   
   tnode (void);
   void addnum (int n);
   void addptr (tnode* p);
   void setop (char o)  { if ( numc > 0 )  ops[numc-1] = o; }
   ~tnode (void);
   
   void first (void);   /* pripravi prvni kombinaci */
   int next (void);   /* pripravi dalsi; vrati nulu, kdyz neni */
   int evaluate (void);
   void print (void);
   
   void firstidx (int idx);
   int nextidx (int idx);
   int evalidx (int idx);
   void printidx (int idx);
};


tnode::tnode (void)
{
   numc = 0;
}

void tnode::addnum (int n)
{
   nums[numc++] = n;
}

void tnode::addptr (tnode* p)
{
   ptrs[numc] = p;
   nums[numc++] = -1;
}

tnode::~tnode (void)
{
   for ( int i = 0;  i < numc;  ++i )
      if ( nums[i] < 0 )  delete ptrs[i];
}

void tnode::first (void)
{
   for ( int i = 0;  i < numc;  ++i )  firstidx (i);
}

int tnode::next (void)
{
   for ( int i = 0;  i < numc;  ++i )
   {
      int r = nextidx (i);
      if ( r )  return r;
      firstidx (i);
   }
   return 0;
}

int tnode::evalidx (int idx)
{
   if ( nums[idx] >= 0 )  return nums[idx];
   return ptrs[idx]->evaluate();
}

int tnode::evaluate (void)
{
   int res = evalidx (0);
   for ( int i = 1;  i < numc;  ++i )
   {
      int r2 = evalidx (i);
      switch ( ops[i-1] )
      {
      case '+':  res += r2;  break;
      case '-':  res -= r2;  break;
      case '*':  res *= r2;  break;
      }
   }
   return res;
}

void tnode::printidx (int idx)
{
   if ( nums[idx] >= 0 )  printf ("%d", nums[idx]);
   else
   {
      putchar ('(');
      ptrs[idx]->print();
      putchar (')');
   }
}

void tnode::print (void)
{
   printidx (0);
   for ( int i = 1;  i < numc;  ++i )
   {
      putchar (ops[i-1]);
      printidx (i);
   }
}

void tnode::firstidx (int idx)
{
   if ( idx > 0 )  ops[idx-1] = '+';
   if ( nums[idx] < 0 )  ptrs[idx]->first();
}

int tnode::nextidx (int idx)
{
   if ( idx == 0 )
   {
      if ( nums[0] < 0 )  return ptrs[0]->next();
      return 0;
   }
   if ( ops[idx-1] == '+' )  { ops[idx-1] = '-'; return 1; }
   if ( ops[idx-1] == '-' )  { ops[idx-1] = '*'; return 1; }
   ops[idx-1] = '+';
   if ( nums[idx] < 0 )  return ptrs[idx]->next();
   return 0;
}


char row [128];
int rpos = 0;

int lex_skip (void)
{
   while ( isspace (row[rpos]) )  ++rpos;
   return rpos;
}

int lex_num (void)
{
   int num = 0;
   while ( isdigit (row[rpos]) )
      num = num * 10 + row[rpos++] - '0';
   return num;
}


tnode* stx_expr (void)
{
   tnode* res = new tnode;
   
   for ( ; ; )
   {
      lex_skip();
      if ( row[rpos] == '(' )
      {
         ++rpos;
         res->addptr (stx_expr());
         lex_skip();
         ++rpos;
      }
      else
         res->addnum (lex_num());
      
      lex_skip();
      if ( row[rpos] == '\0' || row[rpos] == ')' )  break;
   }
   
   return res;
}


int main (void)
{
   FILE* fin = fopen ("dreisam.in", "r");
   int task = 0;
   
   int res;
   while ( fscanf (fin, "%d", &res) == 1 )
   {
      if ( res == 0 )  break;
      
      int ch = 0;
      while (( ch = fgetc (fin)) != '=' )  {}
      fgets (row, 128, fin);
      
      rpos = 0;
      lex_skip();
      tnode* exp = stx_expr();
      
      int ok = 0;
      
      exp->first();
      do
      {
         if ( exp->evaluate() == res )  { ok = 1;  break; }
      } while ( exp->next() );
      
      printf ("Equation #%d:\n", ++task);
      if ( ok )
      {
         printf ("%d=", res);
         exp->print();
         printf ("\n\n");
      }
      else
         printf ("Impossible\n\n");
      
      delete exp;
   }
   
   fclose (fin);
   return 0;
}
